<?php
/**
 * @package     Joomla.Site
 * @subpackage  mod_articles_latest
 *
 * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;


/**
 * Helper for creating the gallery content array
 *
 * @package     Joomla.Site
 * @subpackage  mod_articles_latest
 * @since       1.6.0
 */
abstract class gallery
{
	/**
	 * Retrieve a list of article
	 *
	 * @param   JRegistry  &$params  module parameters
	 *
	 * @return  mixed
	 */
	public static function getList(&$params)
	{
		// Get the gallery content
		$gallery = json_decode($params->get('gallery_settings', ''));	
	

		// Check if we have some images to process
		if (is_object($gallery))
		{
		
			// Get the images
			$gallery = $gallery->images;
		
			// define number of items 
			$count = $params->get('gallery_count', '9');
			
			// Randomize image array
			if ($params->get('random_image'))
			{
				list($usec, $sec) = explode(' ', microtime());
				mt_srand((float) $sec + ((float) $usec * 100000));
				shuffle($images);
			}
			
			//we create the array that will hold the items
			$items = array();
			$i     = 0;
			
			//create an array of items for template
			// We copuld just grab the array but we may want to add items
			// later like get item from images meta data.
			
			
			foreach ($gallery as $item)
			{
			
				if ($i >= $count) break;
				
				// Store the image name
				$item->image = $item->image;
				
				
				// Item Title
				$item->title = $item->title;
				
				// Intro Text
				$item->introtext = $item->introtext;
				
				// Full Text
				$item->fulltext = $item->fulltext;
				
				// Author
				$item->author = $item->author;
				
				// Link
				$item->link = $item->link;
				$item->link_text = $item->link_title;
				
				//  is featured
				$item->featured = $item->featured;
				
				// Date
				$item->created = $item->date;
				
				// Category
				$item->category = $item->category;
				$item->category_alias = strtolower(str_replace(' ', '-', $item->category));
			
				
				// Tags
				$tags = '';
				
				if(isset($item->tags)) {
					
					$tags = explode(',', $item->tags);
					$taglist= array();
					
					foreach ($tags as $key => $tag) {
						
						$title = ltrim($tag, ' ');
						$title = rtrim($title, ' ');
						
						$alias = strtolower(str_replace(' ', '-', $title));
						
						$tagdata = array(
							'title' => $title,
							'link' => 'null',
							'alias'=> $alias
						);
						
						$taglist[$alias] = (object)$tagdata;
						
						$item->tags = $taglist;
					}
					
				} else {
					
					$item->tags = null;
				
				}
				
				
				// Exif
				if(isset($item->exif)) {
					
					$exif = array_filter(explode(';', $item->exif));
					$exif_data = array();
					
					
					foreach ($exif as $key => $attributes) {
						$attributes = explode(':', $attributes);
						$type = $attributes[0];
						$value = $attributes[1];
						$exif_data[$type] = $value;
					}
					
					$item->exif = $exif_data;
					
				} else {
					$item->exif = null;
				}
				
				// Tags that should be nulled
				$item->catlink = "";
				$item->newlink = 0;
				$item->video =false;
				$item->authorLink=false;
				$item->avatar=false;
				$item->tagblock=false;
				$item->rating="";
				
				// Increment the count
				$i++;
				
				// Add all items to an array
				$items[] = $item;
			}

			// Return the items
			return $items;
		}
	}
}
