<?php
/**
 * @package     Joomla.Site
 * @subpackage  mod_articles_latest
 *
 * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

require_once JPATH_SITE . '/components/com_content/helpers/route.php';

JModelLegacy::addIncludePath(JPATH_SITE . '/components/com_content/models', 'ContentModel');

jimport('joomla.user.helper');
jimport('joomla.access.access');


/**
 * Helper for mod_articles_latest
 *
 * @package     Joomla.Site
 * @subpackage  mod_articles_latest
 * @since       1.6.0
 */
abstract class joomla
{
	/**
	 * Retrieve a list of article
	 *
	 * @param   JRegistry  &$params  module parameters
	 *
	 * @return  mixed
	 */
	public static function getList(&$params)
	{
		
		// Content Source
		$source = $params->get('joomla_content_type', 'categories');
		
		// Featured
		$show_featured = $params->get('joomla_featured', '');
		
		// Ordering
		$ordering = $params->get('joomla_ordering', 'title DESC');	
		
		// Item count
		$count = $params->get('j_count', '5');
		
		
		// Link Type
		$link_type = $params->get('joomla_link_type', 'item');
		$link_fallback = $params->get('joomla_link_fallback');
		
		// Define DB
		$db = JFactory::getDbo();
		$query = $db->getQuery(true);
		
		
		// Set current time to see if items should be published
		$nullDate	= $db->getNullDate();
		$date = JFactory::getDate();
		$now = $date->toSql();
		
		// Get the layout item settings
		// We need this to get some of the values for related items.
		
		$settings = json_decode($params->get('layout_settings'));
		
		$strict_readmore = 0;
		
		foreach($settings as $key=>$colcontent) {
			
			foreach ($colcontent as $name =>$item_content) {
				if($name == 'readmore') {
					if(isset($item_content->strict_readmore)) {
		    			$strict_readmore = $item_content->strict_readmore;
		    		}
		    	 }
		    }
		}
		
		
		
		// Access filter
		$access     = !JComponentHelper::getParams('com_content')->get('show_noauth');
		$authorised = JAccess::getAuthorisedViewLevels(JFactory::getUser()->get('id'));
		
		
		// Get view access levels for current user id
		$user = JFactory::getUser();
		$viewLevels = JAccess::getAuthorisedViewLevels(JUserHelper::getUserId($user->username));
		$access_levels = implode(",", $viewLevels);	
		
		if($source=='categories') {
			$cats = json_decode($params->get('joomla_content_categories_limit', ''));
		
			// Cast object to an array
			$catitems = (array)$cats;
			
			// Get catids from array
			$catids = array_keys($catitems);
			
			// Count number of cats to process
			$limitcount = count($catitems);
		
			// Process some things using the Joomla model
			// Get an instance of the generic articles model
			$model = JModelLegacy::getInstance('Articles', 'ContentModel', array('ignore_request' => true));
	
			// Set application parameters in model
			$app       = JFactory::getApplication();
			$appParams = $app->getParams();
			$model->setState('params', $appParams);
		
				// If just a single value then proceed as usual
					if($limitcount <= 1) {
					
						// If no limits on category numbers we just perform the standard query
						$query->select('*');
						$query->from('#__content'); 
						
						if(!empty($catids)) {
							$query->where('catid = ' . implode(',', $catids));
						}
						
						$query->where('state = 1')
							  	->where("access in ($access_levels)")
								->where('publish_down = '.$db->Quote($nullDate).' OR publish_down >= '.$db->Quote($now))
								->where('publish_up <= '.$db->Quote($now));
								
					
						// Featured
						if($show_featured == 0) {
							$query->where('featured = 0');
						} elseif($show_featured == 1) {
							$query->where('featured = 1');
						} 
						
						
						
						if(isset($catids[0])) {
							$limit = $cats->{$catids[0]};
							
							if($limit > $count || $limit == "") {
								$limit = $count;
							}
							
						} else {
							$limit = $count;
						}
						
						// Set the limit for the items as a whole		    			    
						$query->order($ordering);
						
						$db->setQuery($query, 0, $limit);
						$items = $db->loadObjectList();
						
					} else {
					
						// Get specific items
					//	$cats = $params->get('joomla_content_items', '');
					
					
					
					// Loops through the catd ids and limits set
					// catid:limit
					// 42:2
				
					// We need to calculate the new total items to display
					// Check later to see if it's higher or lower than the count amount
					$total = '';
					
				
					foreach ($cats as $catid => $limit) {
						
						
						// If limit is left blank in the settings
						if($limit == "") {
							$limit = $count;
						}
						
						
						// Set up the union query
						${'q'.$catid} = $db->getQuery(true);
					
						// Create the select for each cat
						${'q'.$catid}
						    ->select('*')
						    ->from('#__content')
						    ->where('catid = '.$catid.'')
						    ->where('state = 1')
						    ->where("access in ('$access_levels')")
						    ->where('publish_down = '.$db->Quote($nullDate).' OR publish_down >= '.$db->Quote($now))
						    ->where('publish_up <= '.$db->Quote($now))
						    ->order(''.$ordering.'');
						 
						 	// Featured items
						    if($show_featured == 0) {
						    	${'q'.$catid}->where('featured = 0');
						    } elseif($show_featured == 1) {
						    	${'q'.$catid}->where('featured = 1');
						    } 
						    
						    // Limit the items from this category
						    ${'q'.$catid}->setLimit($limit);
						    
						    $total += $limit;
					}
							
					// Perform the base query
					// First item is a dummy
					// Then loop through the unions
					// created int he previous step
					
					$query
					    ->select('*')
					    ->from('#__content')
					    ->where('1 = 0');
					    
					 foreach ($cats as $catid => $limit) {
					   	$query->union(${'q'.$catid});
					 }
					 
					 
					// Add the order by option
					// A bug in Joomla currently means that we have to
					// Set this manually
				   
				    
				    // Set the limit for the items as a whole		    			    
				    $query .= ' ORDER BY '.$ordering.' ';
				    
				    
				    // Remove the limit that gets set and inherited from the last
				    // item in the loop of union selects
				   // $query = str_replace('LIMIT 0, '.$limit, '', $query);
				    
				    // If the total number of items is less than the count
				    if($total < $count) {
				    	$query .= ' LIMIT 0, ' . $total ;
				    } else {
				    	$query .= ' LIMIT 0, ' . $count ;
				    }
				    
				    $db->setQuery($query);	
					
					// The final array    	    	    
				    $items = $db->setQuery($query)->loadObjectList();	
							
				}
				
		} else {
		
			
			$id = $params->get('joomla_content_items', '');
			
			if($id!=="") {
				$id = implode(",", $id);	
				
				$db = JFactory::getDbo(); 
				$query = $db->getQuery(true); 
				$query->select(array('*')) 
				      ->from($db->quoteName('#__content')) 
				      ->where('ID in ('.$id.')');
				      
				      if($show_featured == 0) {
				      	$query->where('featured = 0');
				      } elseif($show_featured == 1) {
				      	$query->where('featured = 1');
				      } 
				      
				$query->order(''.$ordering.'');
				 $db->setQuery($query,0,$count); 
				 
				 $items = $db->loadObjectList(); 
			} else {
				echo '<div class="alert alert-warning">';
				echo JText::_('NO_ITEMS_SELECTED');
				echo '</div>';
				return;
			}
		  }
		
		// counter
		$i = 1;
		
		
		// Manual Links
		$manual_links = null;
		
		if($link_type =="manual") {
			$manual_links = explode(PHP_EOL, $params->get('joomla_manual_links'));
		}
		
		if(is_array($items)) {
			
			foreach ($items as $key => $item)
			{
				
				/**************************************************
				 * Link
				 *************************************************/
				
				$category = self::get_joomla_cat($item->catid); 
			
				$item->category = $category[0]->title;
				$item->category_title = $item->category;
				$item->category_alias = $category[0]->alias; 
				$item->catlink = 'index.php?option=com_contact&view=category&id='.$item->catid;
				$item->slug = $item->id . ':' . $item->alias;
				$item->catslug = $item->catid . ':' . $item->category_alias;
			
				$item->link = null;
					
				if($link_type =="manual") {
					if(isset($manual_links[$key])) {
						$item->link = $manual_links[$key];
					}  else {
						if($link_fallback) {
								$item->link = JRoute::_(ContentHelperRoute::getArticleRoute($item->slug, $item->catslug));
							} else {
								$item->link = null;
							}
					}
				
				} elseif($link_type == "alternate") {
					
					 $altlinks = json_decode($item->urls);
					
                    	if(isset($altlinks->urla) and !empty($altlinks->urla)) {
                    	    $item->link = $altlinks->urla;
                    	} else {
                    		
                    		if($link_fallback) {
                    		
                    			$item->link = JRoute::_(ContentHelperRoute::getArticleRoute($item->slug, $item->catslug));
                    		} else {
                    			$item->link = null;
                    		}
                    	}
				
				} else {
					
					if (in_array($item->access, $authorised))
							{
							// We know that user has the privilege to view the article
							$item->link = JRoute::_(ContentHelperRoute::getArticleRoute($item->slug, $item->catslug));
					}
					else
					{
						$item->link = JRoute::_('index.php?option=com_users&view=login');
					}
					
					if($strict_readmore && $item->fulltext =="") {
						$item->link = null;
					}
				}
				
				
				
				
				
				/**************************************************
				 * Category
				 *************************************************/
				 
				$item->category = $item->category_title;
				
				if($access) {
	             	$item->catlink = JRoute::_(ContentHelperRoute::getCategoryRoute($item->catslug).'&layout=blog');
	            } else {
	                $item->catlink = JRoute::_('index.php?option=com_user&view=login');
	            }
				
				
				/**************************************************
				 * Image
				 *************************************************/
				$item->image = "";
				$images = json_decode($item->images);
				
				
				// Try to get image intro
				if (isset($images->image_intro) and !empty($images->image_intro)) {
					$item->image = $images->image_intro;		
				}
				else {
					// Try to extract the first image from full text
					$imageHTML = $item->introtext;
					$imageHTML .= "alt='...' title='...' />";
	
					$pattern = '/<img[^>]+src[\\s=\'"]' . '+([^"\'>\\s]+)/is';
	
					if (preg_match($pattern, $imageHTML, $match)) {
						$item->image = (string) $match[1];
					}
				}
				
				
				// Try to get image intro
				if (isset($images->image_fulltext) and !empty($images->image_fulltext)) {
					$item->fulltext_image = $images->image_fulltext;		
				}
				else {
					// Try to extract the first image from full text
					$item->fulltext_image = "";
				}
				
				
			
				/**************************************************
				 * Meta
				 *************************************************/
				
				$item->metadescription = $item->metadesc;
				
				
				/**************************************************
				 * Ratings
				 *************************************************/
				 
				$query = 'SELECT *' . ' FROM #__content_rating' . ' WHERE content_id = ' . $item->id;
	            $db->setQuery($query);
	            $rating = $db->loadObject();
	            
	            if(isset($rating->rating_sum)) {
	            	$item->rating = $rating->rating_sum;
				} else {
					$item->rating = 0;
				}
				
							
				/**************************************************
				 * Tags
				 *************************************************/
				$article_tags = new JHelperTags;      
				$item->tag_filter = $article_tags->getItemTags('com_content.article', $item->id);
				$item->tagLayout = new JLayoutFile('joomla.content.tags');
				
				$item->tagblock = $item->tagLayout->render($item->tag_filter);
				
				$item->tags = $item->tagblock;
			
				$item->tags = $item->tag_filter;
				
				$taglist = array();
				
				foreach ($item->tags as $key => $tag) {
					
					$title = $tag->title;
					$alias = $tag->alias;
					$id = $tag->id;
					
					$link = JRoute::_(TagsHelperRoute::getTagRoute($id . '-' . $alias));
					
					$tagdata = array(
						'title' => $title,
						'alias' => $alias,
						'link' => $link
					);
					
					$taglist[$alias] = (object)$tagdata;
				}
				
				
				/**************************************************
				 * Author
				 *************************************************/
				$user = JFactory::getUser($item->created_by);
				$item->author = $user->name;
				
				
				/**************************************************
				 * Date
				 *************************************************/
				$item->date = $item->created;
				$item->publishdate = $item->publish_up;
				
				
				// Time Since
				$item->time_since = self::humanTiming(strtotime($item->publishdate));
				
				
				/**************************************************
				 * Video
				 *************************************************/
				 
				preg_match('#<iframe([^>]+)><\/iframe>#', $item->introtext, $item->video);
				if(isset($item->video[0])) {
					$item->video = $item->video[0];
				} else {
					$item->video = false;
				}
				
				// Turn the array back into an object
				$item->tags = $taglist;
				
				$item->pinit ="";
				
				$i ++;
			}
	
			return $items;
		}
	}
	
	public static function get_joomla_cat($category) {
		$db = JFactory::getDbo(); 
		$query = $db->getQuery(true); 
		$query->select(array('title', 'alias')) 
		      ->from($db->quoteName('#__categories')) 
			  ->setLimit(1)
			  ->where($db->quoteName('id') . ' LIKE '. $category);
		$db->setQuery($query); 
		$rows = $db->loadObjectList();
		return $rows;
	}
	
	public static function humanTiming ($time)
	{
	
	    $time = time() - $time; // to get the time since that moment
	    $time = ($time<1)? 1 : $time;
	    $tokens = array (
	        31536000 => 'year',
	        2592000 => 'month',
	        604800 => 'week',
	        86400 => 'day',
	        3600 => 'hour',
	        60 => 'minute',
	        1 => 'second'
	    );
	
	    foreach ($tokens as $unit => $text) {
	        if ($time < $unit) continue;
	        $numberOfUnits = floor($time / $unit);
	        return $numberOfUnits.' '.$text.(($numberOfUnits>1)?'s':'');
	    }
	
	}
	
}
