<?php
/**
 * @package     Joomla.Site
 * @subpackage  mod_articles_latest
 *
 * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;


require_once JPATH_SITE . '/components/com_content/helpers/route.php';


/**
 * Helper for mod_articles_categories
 *
 * @package     Joomla.Site
 * @subpackage  mod_articles_categories
 *
 * @since       1.5
 */


abstract class joomla_categories
{
	/**
	 * Retrieve a list of article
	 *
	 * @param   JRegistry  &$params  module parameters
	 *
	 * @return  mixed
	 */
	public static function getList(&$params)
	{
		$cats = json_decode($params->get('joomla_categories_categories_limit', ''));
		$order = $params->get('joomla_categories_ordering', 'name DESC');	
		$count = $params->get('j_cat_count', '5');
		
		// Cast object to an array
		$catitems = (array)$cats;
		
		// Get catids from array
		$catids = array_keys($catitems);
		
		// Get view access levels for current user id
		$user = JFactory::getUser();
		$viewLevels = JAccess::getAuthorisedViewLevels(JUserHelper::getUserId($user->username));
		$access_levels = implode(",", $viewLevels);	
		
		// Link Type
		$link_type = $params->get('jcat_link_type', 'item');
		$link_fallback = $params->get('jcat_link_fallback');
		
		// If no limits on category numbers we just perform the standard query
		$db = JFactory::getDBO();
		$query	= $db->getQuery(true);
		$query->select('a.*');
		$query->from('#__categories AS a'); 
		
		if(!empty($catids)) {
			$query->where('a.id in (' . implode(',', $catids) . ')');
		    $query->where('a.published = 1');
		}
		
		$query->where('published = 1')->where("access in ($access_levels)");
		
		if($order =='title') {	
			$query->order('title ASC');
		} elseif($order =='title_reverse') {
			$query->order('title DESC');
		} elseif($order =='random') {
			$query->order('RAND()');
		} elseif($order =='order') {
			$query->order('lft ASC');
		} elseif($order =='order_reverse') {
			$query->order('lft DESC');
		} 

		$db->setQuery($query, 0, $count);
		$categories = $db->loadObjectList();
			
		// Manual Links
		$manual_links = null;
		
		if($link_type =="manual") {
			$manual_links = explode(PHP_EOL, $params->get('jcat_manual_links'));
		}
		

		if(is_array($categories)) {
			foreach ($categories as $key=>$cat) {
				
				// Create the new class
				$item = new stdClass();
				$item->title = $cat->title;
				
				// Count number of items in a category
				$item->catcount= self::count_items($cat->id);
				
				$item->title = $item->title;
				
				$image = json_decode($cat->params);
				
				if(isset($image->image)) {
					$item->image = $image->image;
				} else {
					$item->image = null;
				}
				
				$item->introtext = $cat->description;
				
				if($link_type =="manual") {
					
					if(isset($manual_links[$key])) {
						$item->link = $manual_links[$key];
					}  else {
						if($link_fallback) {
								$item->link = JRoute::_(ContentHelperRoute::getCategoryRoute($cat->id, $cat->id));
						} else {
							$item->link = null;
						}
					}
				
				} else {
					$item->link = JRoute::_(ContentHelperRoute::getCategoryRoute($cat->id, $cat->id));
				}
				
				if($cat->parent_id !=="root") {
					$parent_cat = self::get_parent($cat->parent_id);
					if(isset($parent_cat[0])) {
						$parent_cat = $parent_cat[0];
						$item->category = $parent_cat->title;
						$item->category_alias = $parent_cat->alias; 
					}
				} else {
					$item->category = "Root";
					$item->category_alias = "root";
				}
				
				$item->date = $cat->created_time;
				
				
				
				// Tags that should be nulled
				$item->created= false;
				$item->catlink = false;
				$item->featured = 0;
				$item->newlink = 0;
				//$item->$id = false;
				$item->video =false;
				$item->authorLink=false;
				$item->author=false;
				$item->avatar=false;
				$item->tagblock=false;
				$item->tags=null;
				$item->rating="";
				$item->fulltext = false;
				
				$items[] = $item;
			}
			return $items;
		}
		
	}
	
	public static function get_parent($parent_id) {
		$db = JFactory::getDbo(); 
		$query = $db->getQuery(true); 
		$query->select(array('title', 'alias')) 
		      ->from($db->quoteName('#__categories')) 
		      ->setLimit(1)
			  ->where($db->quoteName('id') . ' = '. $parent_id);
		$db->setQuery($query); 
		$rows = $db->loadObjectList();
		return $rows;
	}
	
	public static function count_items($id) {
		$db = JFactory::getDBO();
		$query = "SELECT * FROM #__content WHERE catid='$id' and state='1'";
		$db->setQuery($query);
		$replyAG = $db->query();
		$rowsAG = $db->getNumRows();
		return $rowsAG;
	}
}
	