<?php
/**
 * @package		Zen Tools 2
 * @subpackage	Zen Tools 2
 * @author		Joomla Bamboo - design@joomlabamboo.com
 * @copyright 	Copyright (c) 2015 Joomla Bamboo. All rights reserved.
 * @license		GNU General Public License version 2 or later
 * @version		1.0.5
 */

defined('_JEXEC') or die;

// Include the syndicate functions only once
require_once __DIR__ . '/includes/zentools2helper.php';

// Instantiate the class
$zen = new ZenTools2Helper();

// Import libraries
jimport('joomla.filesystem.file');
jimport('joomla.filesystem.folder');

// Define paths
// Absolute Paths
$base_root = JPATH_ROOT . '/modules/mod_zentools2/';
$media_root = JPATH_ROOT . '/media/mod_zentools2/';
$block_root = JPATH_ROOT . '/modules/mod_zentools2/tmpl/blocks';

// Relative Paths
$base_path = JURI::BASE().'/modules/mod_zentools2/';
$layout_path = $base_path . 'tmpl/';
$block_path = $layout_path . 'blocks';
$media_path = $zen->media_path;


// Determine the content source
$source = $params->get('source', 'default');

// Get the helper for the specific source
if($source !=="default") {
	require_once dirname(__FILE__) . '/includes/'. $source.'.php';
} else {
	$application = JFactory::getApplication();
	$application->enqueueMessage(JText::_('SELECT_A_CONTENT_SOURCE'), 'error');
	return;
}

// Get the helper for the specific source
require_once dirname(__FILE__) . '/includes/'. $source.'.php';
	
// Set up list of items based on each source
${$source.'_list'} = $source::getList($params);
$content_source_list[] = ${$source.'_list'};

// Determine the layout to use
$layout_type = $params->get('layout', 'grid');

// Get the doc
$doc = JFactory::getDocument();

$load_css = $params->get('load_css');

if($load_css > 0) {

	// Are we loading the laster css
	$doc->addStyleSheet($media_path. 'css/zentools.min.css');
	//$doc->addStyleSheet($media_path. 'css/zentools.css');
	
	// Are we loading custom css as well
	if($load_css > 1) {
		
		$path = JPATH_ROOT. '/media/mod_zentools2/css/custom/zentools-'.$module->id.'.min.css';
		
		if(JFILE::exists($path)) {
			$doc->addStyleSheet($media_path. 'css/custom/zentools-'.$module->id.'.min.css');
		} 
	}
} 

// Load Joomla content language file
// We need to check this is loading for read more.
$lang = JFactory::getLanguage();
$extension = 'com_content';
$base_dir = JPATH_SITE;
$language_tag = 'en-GB';
$reload = true;
$lang->load($extension, $base_dir, $language_tag, $reload);



// Get the params
$layout = json_decode($params->get('layout_settings'));

if(is_object($layout)) {

	$options = json_decode($params->get('options'));
	
	if(is_object($options)) {
	
		// Create the settings object
		$settings = new stdClass();
		
		$settings->id = $module->id;
		
		// Add layout setting to settings object
		$settings->layout = $layout; 
		
		
				
		// Get the lightbox
		$lightbox = json_decode($params->get('lightbox_settings')); 
		
		// Just in case lightbox isnt set
		if(!is_object($lightbox)) {
			$lightbox = new stdClass();
			$lightbox->enable = false;
		}
		
		// Add the lightbox object to settings to make it easier to pass to the parts
		$settings->lightbox = $lightbox;
		
		// Specific options for this layout
		// eg max cols = 3 etc
		$options = json_decode($params->get('options'));
		
		
		// Determines the layout param for lazyloading.
		// If wait till images loaded then datasrc = data-src else src.
		$settings->datasrc = 'src';
		
		if(isset($options->imagesloaded)) {
			if($options->imagesloaded) {
				$settings->datasrc = 'data-src';
			} 
		}
		
		
		// Creates an array for the columns
		// This used in the layotu files to make rows of content within each item
		$columns = explode(',', $params->get('layout_columns'));
	
		// Load jQuery
		#todo make this more flexible
		if($params->get('load_jquery', '1')) {
			JHtml::_('jquery.framework');
		}
		
		#todo make loading of social scripts better
		if(isset($layout->{0}->like) || isset($layout->{1}->like) || isset($layout->{2}->like) || isset($layout->{3}->like)) {
			$doc->addScript($media_path .'js/social/facebook.js');
		}
		
		if(isset($layout->{0}->tweet) || isset($layout->{1}->tweet) || isset($layout->{2}->tweet) || isset($layout->{3}->tweet)) {
			$doc->addScript($media_path .'js/social/twitter.js');
		}
		
		// Set up the list variable.
		$list = ${$source.'_list'};
	
		// Module id
		$id = $module->id;	

	
	
		// Load assets
		// Files are laoded here based on the asset group in the
		// corresponding layout xml file.
		// 
		// If debug is enabled then load all of the js files separately
		// if not then load the combined file
		//
		
		
		if(!$params->get('disable_js')) {
			$assets = $zen->load_assets($layout_type);
			
			if($lightbox->enable) {
				$doc  = JFactory::getDocument();
				$doc->addScript($media_path . 'js/lightbox/magnific.js');
				$doc->addScript($media_path . 'js/lightbox/lightbox.js');
			}
			
			
			// Add animation
			$doc->addScript($media_path . 'js/animation/wow.min.js');
			$doc->addScript($media_path . 'js/animation/wow-init.js');
			
			if($params->get('master_file', '0')) {
					
				$custom = $media_root . 'js/zentools-'.$id.'.min.js';
				
				if(jfile::exists($custom)) {
					$doc->addScript($media_path . 'js/zentools-'.$id.'.min.js');
				} else {
					$doc->addScript($media_path . 'js/zentools.min.js');
				}
				
			} else {
			
				if(is_array($assets)) {
					foreach ($assets as $key => $asset) {
						$doc->addScript($media_path . $asset);
					}
				}
			}
		}
		
		
		
		
		// Get the layout type
		// If no content for layout exists
		// display a warning
		
		if(is_array($list)) {
			// Load the template file
			require JModuleHelper::getLayoutPath('mod_zentools2', $layout_type);
		} else {
			echo '<div class="alert alert-warning">';
			echo JText::_('MODULE_CONTENT_NOT_AVAILABLE');
			echo '</div>';
		}
		
		
		if($params->get('debug', '0')) {
			foreach ($settings as $key => $setting) {
				if(is_object($setting)) {
				
					echo '<code>';
					echo '<h2>' .$key .  ' Settings</h2>';
					echo '<ul>';
					
					foreach ($setting as $key => $option) {
						
						if(is_object($option)) {
							foreach ($option as $type => $option_setting) {
								if(is_object($option_setting)) {
									echo '<h3>' . $type . '</h3>';
									foreach ($option_setting as $name => $value) {
										echo '<li>';
										echo $name.' - '.$value;
										echo '</li>';
									}
								} else {
									echo '<li>';
									echo $type.' - '.$option_setting;
									echo '</li>';
								}
							}
						} else {
							echo '<li>';
							echo $key.' - '.$option;
							echo '</li>';
						}
						
					}
			
					echo '</ul>';
					echo '</code>';	
				}
			}
			
			echo '<code>';
			echo '<h2>Display Settings</h2>';
			echo '<ul>';
			foreach ($options as $key => $option) {
				echo '<li>'.$key.' - '.$option.'</li>';
			}
			echo '</ul>';
			echo '</code>';
		}
	}
	else {
		$application = JFactory::getApplication();
		$application->enqueueMessage(JText::_('MODULE_SETTINGS_NOT_AVAILABLE'), 'error');
	}
}
else {
	$application = JFactory::getApplication();
	$application->enqueueMessage(JText::_('MODULE_SETTINGS_NOT_AVAILABLE'), 'error');
}